@@ -12,7 +12,7 @@ from OCC.Core.Geom2dGcc import Geom2dGcc_Circ2d2TanOn, Geom2dGcc_QualifiedCurve,
 from OCC.Core.GeomAPI import geomapi
 from OCC.Core.gp import gp_Ax2, gp_Pnt2d, gp_Pln, gp_Circ, gp_Circ2d, gp_Ax3
 
-from pyoccad.create import CreateDirection, CreatePoint, CreateCurve, CreateLine
+from pyoccad.create import CreateDirection, CreatePoint, CreateCurve, CreateLine, CreateAxis
 from pyoccad.typing import PointT, DirectionT
 
 
@@ -42,7 +42,7 @@ class CreateCircle:
     @staticmethod
     def from_radius_and_center(radius: float,
                                center: PointT = (0, 0, 0),
-                               normal: DirectionT = (0, 0, 1)) -> Union[Geom2d_Circle, Geom_Circle]:
+                               normal: DirectionT = None) -> Union[Geom2d_Circle, Geom_Circle]:
         """Create a circle with a radius r around a point center, in a plane defined by a normal vector.
 
         Parameters
@@ -52,7 +52,7 @@ class CreateCircle:
         center: PointT, optional
             The center of the circle {default=(0., 0., 0.)}
         normal: DirectionT, optional
-            The normal vector {default=(0., 0., 1.)}
+            The normal vector {default=None will result in (0., 0., 1.) in 3D or (0., 1.) in 2D}
 
         Returns
         -------
@@ -62,10 +62,13 @@ class CreateCircle:
         from pyoccad.measure import MeasurePoint
 
         dim = MeasurePoint.dimension(center)
+        if normal is None:
+            normal = (0., 0., 1.) if dim ==3 else (0., 1.)
+        axis = CreateAxis.as_axis((center, normal))
         if dim == 2:
-            circle = GCE2d_MakeCircle(CreatePoint.as_point(center), radius).Value()
+            circle = GCE2d_MakeCircle(axis, radius).Value()
         else:
-            circle = GC_MakeCircle(CreatePoint.as_point(center), CreateDirection.as_direction(normal), radius).Value()
+            circle = GC_MakeCircle(axis, radius).Value()
         return circle
 
     @staticmethod
