@@ -1,4 +1,4 @@
-from OCC.Core.Adaptor3d import Adaptor3d_Surface, Adaptor3d_HSurface
+from OCC.Core.Adaptor3d import Adaptor3d_Surface
 from OCC.Core.BRepAdaptor import BRepAdaptor_Surface
 from OCC.Core.Geom import Geom_Surface
 from OCC.Core.GeomAdaptor import GeomAdaptor_Surface
@@ -30,7 +30,5 @@ class CreateSurface:
             return BRepAdaptor_Surface(surface)
         if isinstance(surface, Adaptor3d_Surface):
             return surface
-        if isinstance(surface, Adaptor3d_HSurface):
-            return surface.Surface()
 
         raise TypeError('Unsupported type "{}".'.format(type(surface)))
