@@ -306,10 +306,10 @@ class ShapeGroup(PyoccadGroup):
         nVtx = T.NbNodes()
         vtx = []
         idx = []
-        nodes = T.Nodes()
         tri = T.Triangles()
 
-        for pt in nodes:
+        for pt_idx in range(1, nVtx+1):
+            pt = T.Node(pt_idx)
             for d in range(1, 4):
                 vtx.append(pt.Coord(d))
 
