@@ -5,6 +5,8 @@ from pyoccad.measure import solid
 from pyoccad.tests import TestCase
 from pyoccad.transform import Scale
 
+import pytest
+
 
 class ScaleTest(TestCase):
 
@@ -13,14 +15,12 @@ class ScaleTest(TestCase):
         self.assertAlmostSameCoord(solid.center(box), (0, 0, 0))
         self.assertAlmostEqual(1, solid.volume(box))
 
-        result = Scale.from_factor(box, 10)
-        self.assertAlmostSameCoord(solid.center(box), (0, 0, 0))
-        self.assertAlmostEqual(1000, solid.volume(box))
-        self.assertIsNone(result)
+        with pytest.raises(RuntimeError):
+            Scale.from_factor(box, 10, inplace=True)
 
         result = Scale.from_factor(box, 10, inplace=False)
         self.assertAlmostSameCoord(solid.center(box), (0, 0, 0))
-        self.assertAlmostEqual(1000, solid.volume(box))
+        self.assertAlmostEqual(1, solid.volume(box))
         self.assertIsInstance(result, TopoDS_Solid)
         self.assertAlmostSameCoord(solid.center(result), (0, 0, 0))
-        self.assertAlmostEqual(1000000, solid.volume(result))
+        self.assertAlmostEqual(1000, solid.volume(result))
